@@ -162,6 +162,18 @@ class File:
         self.__rels_path = "/".join([dirname, "_rels", filename + ".rels"])
         return self.__rels_path
 
+    @property
+    def rels_element(self) -> EtreeElement | None:
+        """Root element of the rels file.
+
+        :return: Root element of the rels file.
+        :raise KeyError: If the rels file is not found
+        """
+        rels_files = [x for x in self.context.files if x.Target == self._rels_path]
+        if len(rels_files) == 1:
+            return rels_files[0].root_element
+        return None
+
     @property
     def rels(self) -> dict[str, str]:
         """Get rIds mapped to values.
@@ -189,16 +201,10 @@ class File:
         Not every xml file with have a rels file. Return an empty dictionary if the
         rels file is not found.
         """
-        if self.__rels is not None:
-            return self.__rels
-
-        try:
-            unzipped = self.context.zipf.read(self._rels_path)
-            tree = etree.fromstring(unzipped)
-            self.__rels = {str(x.attrib["Id"]): str(x.attrib["Target"]) for x in tree}
-        except KeyError:
-            self.__rels = {}
-        return self.__rels
+        rels_element = self.rels_element
+        if rels_element is not None:
+            return {str(x.attrib["Id"]): str(x.attrib["Target"]) for x in rels_element}
+        return {}
 
     @property
     def root_element(self) -> EtreeElement:
@@ -451,10 +457,11 @@ class DocxReader:
         :param filename: path to output file (presumably *.docx)
 
         xml (root_element) attributes are cached, so these can be altered and saved.
-        This allows saving a copy of the input docx after the ``merge_elems`` operation.
-        Also allows some light editing like search and replace.
+        This allows saving a copy of the input docx after the ``merge_elems``
+        operation. Also allows some light editing like search and replace.
         """
-        content_files = [x for x in self.files if x.Type in CONTENT_FILE_TYPES]
+        overwrite = [*CONTENT_FILE_TYPES, "relationships"]
+        content_files = [x for x in self.files if x.Type in overwrite]
         with zipfile.ZipFile(f"{filename}", mode="w") as zout:
             _copy_but(self.zipf, zout, {x.path for x in content_files})
             for file in content_files:
