@@ -4,11 +4,10 @@
 :created: 4/3/2021
 """
 
-from docx2python.attribute_register import Tags
+from docx2python.attribute_register import Tags, get_prefixed_tag
 from docx2python.docx_reader import DocxReader
 from docx2python.main import docx2python
-
-from .conftest import RESOURCES
+from tests.conftest import RESOURCES
 
 
 class TestFileObject:
@@ -24,7 +23,7 @@ class TestFileObject:
         context = DocxReader(RESOURCES / "example.docx")
         assert (
             full_extraction.body_runs
-            == context.file_of_type("officeDocument").get_content()
+            == context.file_of_type("officeDocument").get_text()
         )
         context.close()
         full_extraction.close()
@@ -37,10 +36,12 @@ class TestFileObject:
         context = DocxReader(RESOURCES / "example.docx")
         document_xml = context.file_of_type("officeDocument")
         first_par = next(
-            x for x in document_xml.root_element.iter() if x.tag == Tags.PARAGRAPH
+            x
+            for x in document_xml.root_element.iter()
+            if get_prefixed_tag(x) == Tags.PARAGRAPH
+        )
+        assert [[[[full_extraction.body_runs[0][0][0][0]]]]] == document_xml.get_text(
+            first_par
         )
-        assert [
-            [[[full_extraction.body_runs[0][0][0][0]]]]
-        ] == document_xml.get_content(first_par)
         context.close()
         full_extraction.close()
