@@ -19,8 +19,7 @@ Symbols are captured in the docx content files as ``<sym>`` elements.
 """
 
 from docx2python.main import docx2python
-
-from .conftest import RESOURCES
+from tests.conftest import RESOURCES
 
 
 def test_symbols() -> None:
